==> haskell-hasql-pool-0.5.2.2-368-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-pool
version:              0.5.2.2
visibility:           public
id:                   hasql-pool-0.5.2.2-6xQfhXWoPJhCJEfktn6LdT
key:                  hasql-pool-0.5.2.2-6xQfhXWoPJhCJEfktn6LdT
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-pool 
synopsis:             A pool of connections for Hasql
category:             Hasql, Database, PostgreSQL
abi:                  421da020625613fc2dfc2f46aec95a34
exposed:              True
exposed-modules:      Hasql.Pool
hidden-modules:       Hasql.Pool.Prelude Hasql.Pool.ResourcePool
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasql-pool-0.5.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasql-pool-0.5.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasql-pool-0.5.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-pool
hs-libraries:         HShasql-pool-0.5.2.2-6xQfhXWoPJhCJEfktn6LdT
depends:
    base-prelude-1.6.1.1-GKFFatabSp72iGYTIzDMDA
    hasql-1.5.0.5-9DBvlkrLeHz6kq9IpKeOv2
    resource-pool-0.2.3.2-Ialdc56ouwKEOPaqifHSOL time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html:         /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-pool-0.5.2.2-369-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-pool
version:              0.5.2.2
visibility:           public
id:                   hasql-pool-0.5.2.2-9Tpdp1WCtyS9EXyFmB0S6Q
key:                  hasql-pool-0.5.2.2-9Tpdp1WCtyS9EXyFmB0S6Q
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-pool 
synopsis:             A pool of connections for Hasql
category:             Hasql, Database, PostgreSQL
abi:                  388a67c94efca45a0811553ec9cda085
exposed:              True
exposed-modules:      Hasql.Pool
hidden-modules:       Hasql.Pool.Prelude Hasql.Pool.ResourcePool
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasql-pool-0.5.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasql-pool-0.5.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasql-pool-0.5.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-pool
hs-libraries:         HShasql-pool-0.5.2.2-9Tpdp1WCtyS9EXyFmB0S6Q
depends:
    base-prelude-1.6.1.1-GKFFatabSp72iGYTIzDMDA
    hasql-1.5.0.5-G0Qum68lPyK2IfU9Q4xYR0
    resource-pool-0.2.3.2-Ialdc56ouwKEOPaqifHSOL time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html:         /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
